from typing import Any, Callable

# Type aliases for semantic resolvers and instruction encoders.
# Using Any to avoid circular imports (capabilities/ imports from eep/).
type SemanticResolver = Callable[[dict[str, Any], dict[str, Any]], Any | None]
type InstructionEncoder = Callable[[Any], Any]  # Instruction → RawEEPMessage



from enocean_async import Manufacturer


def test_manufacturer_values():
    assert Manufacturer.ENOCEAN_GMBH.value == 0x00B
    assert Manufacturer.ENOCEAN_GMBH.friendly_name == "EnOcean GmbH"
    assert str(Manufacturer.ENOCEAN_GMBH) == "EnOcean GmbH"
